====================
STIXpy Documentation
====================

The STIXpy documentation is broken down into four keys areas.

* **Tutorials** start here if you are new to STIX or STIXpy as this material wil help you lean to analyse STIX data in STIXpy.
* **How-to Guides** provide short, focused guides on common tasks go here if  you need to find out how to do X.
* **Discussions** are longer explanation of design choices or historical aspects of STIXpy go here if you want or need to know more they 'why' than 'how'.
* **Reference** technical descriptions of the software such as classes, functions, argument, keywords etc go here to get the details and also changes


.. grid:: 1 2 2 2
    :gutter: 3

    .. grid-item-card::
        :class-card: card

        Tutorials
        ^^^^^^^^^

        .. toctree::
            :maxdepth: 1

            quickstart


    .. grid-item-card::
        :class-card: card

        How-to Guides
        ^^^^^^^^^^^^^

        .. toctree::
            :maxdepth: 1

            dev_guide

    .. grid-item-card::
        :class-card: card

        Discussions
        ^^^^^^^^^^^^^^^

        .. toctree::
            :maxdepth: 1

            stix

    .. grid-item-card::
        :class-card: card

        Reference
        ^^^^^^^^^^

        .. toctree::
            :maxdepth: 1

            code_ref/index
            whatsnew/index
